C
C Common block for kinematics ntuple data
C
C Flags for the various blocks
C
        INTEGER ntupleOutputUnit
        PARAMETER (ntupleOutputUnit = 30)
        INTEGER geantRzUnit
        PARAMETER (geantRzUnit = 31)
        INTEGER nOutputFlags
        PARAMETER (nOutputFlags = 13)
        INTEGER outputFlags(nOutputFlags)
        COMMON /NTOUTF/ outputFlags
        INTEGER kineFlag, beamFlag, vectorFlag
        INTEGER  escapeFlag
        INTEGER minosFlag, stminFlag, 
     +    rawhitFlag, rawhitSideFlag
        INTEGER dighitFlag, rectrkFlag, truthFlag
        PARAMETER (kineFlag = 1)
        PARAMETER (beamFlag = 2)
        PARAMETER (vectorFlag = 3)
        PARAMETER (truthFlag = 4)
        PARAMETER (escapeFlag = 5)
        PARAMETER (minosFlag = 6)
        PARAMETER (stminFlag = 7)
        PARAMETER (rawhitFlag = 8)
        PARAMETER (dighitFlag = 9)
        PARAMETER (rawhitSideFlag = 10)
C
C Name of the output Ntuple file (default = 'ntuple.hbook')
C
        INTEGER outputFileName(32)
        COMMON /NTONAM/ outputFileName
C
C Header info
C
        INTEGER NRUN,NEV,NEVENTCODE,ICC
        COMMON/RUN/NRUN,NEV,NEVENTCODE,ICC
C
        REAL EWGHT,SWGHT
        COMMON/WGHT/EWGHT,SWGHT
C
C Beam weights
C
        REAL FLUXWGT(4)
        COMMON/BEAMWGT/FLUXWGT
C
C Event truth history
C 
C     All particle codes are PDG convention
C     Particle list includes all principal particles tracked by GEANT
C     "Principal" means produced from primary interaction, by secondary
C     hadronic interaction, or decay
C     Secondary neutrinos are not listed
C     Incoming neutrino and target are not on the list.
C     Primary particles have mother track# 0
C
C     NTRUTH          number of tracks
C     NPTRUE(NTRUTH)  PDG particle code
C     MOTHER(NTRUTH)  Index of mother particle (or 0)
C     ORIGIN(NTRUTH)  CHAR*4 name of mechanism creating particle (e.g. DCAY)
C     VXTRUE(NTRUTH)  Creation vertex
C     VYTRUE(NTRUTH)
C     VZTRUE(NTRUTH)
C     VTTRUE(NTRUTH)
C     PXTRUE(NTRUTH)  4-momentum at creation
C     PYTRUE(NTRUTH)
C     PZTRUE(NTRUTH)
C     PETRUE(NTRUTH)
C     QTRUEID(NTRUTH) Recorded energy deposit in inner detector hits
C     ETRUEEX(NTRUTH) Total kinetic energy of escaping products
C
        INTEGER MAXNTRK
        PARAMETER (MAXNTRK = 128)
        INTEGER NTRUTH, NPTRUE, NTMOTH, NTPRIM, NORIG
        REAL VXTRUE, VYTRUE, VZTRUE, VTTRUE
        REAL PXTRUE, PYTRUE, PZTRUE, PETRUE
        REAL QTRUEID, ETRUEEX
        LOGICAL STOPPED
        COMMON/TRUTH/NTRUTH,NPTRUE(MAXNTRK),NTMOTH(MAXNTRK),
     &               NTPRIM(MAXNTRK),NORIG(MAXNTRK),
     &               VXTRUE(MAXNTRK),VYTRUE(MAXNTRK),
     &               VZTRUE(MAXNTRK),VTTRUE(MAXNTRK),
     &               PXTRUE(MAXNTRK),PYTRUE(MAXNTRK),
     &               PZTRUE(MAXNTRK),PETRUE(MAXNTRK),
     &               QTRUEID(MAXNTRK),ETRUEEX(MAXNTRK),
     &               STOPPED(MAXNTRK)

C
C Escaped particles
C
        INTEGER NESCAPE,NPESCAPE(500),NTESCAPE(500)
        REAL NXE(500),NYE(500),NZE(500)
        REAL NPEX(500),NPEY(500),NPEZ(500),NPEE(500)
        COMMON/ESCAPE/NESCAPE,NPESCAPE,NTESCAPE,
     +   NXE,NYE,NZE,
     +   NPEX,NPEY,NPEZ,NPEE
C
C MINOS Entering particles
C
       INTEGER NMINOS,NPMINOS(100),NTMINOS(100)
       REAL NMIX(100),NMIY(100),NMIZ(100)
       REAL NMIPX(100),NMIPY(100),NMIPZ(100),NMIE(100)
       COMMON/MINOS/NMINOS,NPMINOS,NTMINOS,NMIX,NMIY,NMIZ,
     +  NMIPX,NMIPY,NMIPZ,NMIE
C 
C MINOS stopping particles
C
        INTEGER NSTMINOS,NPSTMINOS(100),NTSTMINOS(100),NPLST(100)
        REAL NMISTX(100),NMISTY(100),NMISTZ(100)
        COMMON/STMIN/NSTMINOS,NPSTMINOS,NTSTMINOS,NPLST,
     +  NMISTX,NMISTY,NMISTZ
C
C Raw hits
C
       INTEGER MAXNRAW
       PARAMETER (MAXNRAW = 3500)
       INTEGER NHIT,MODHIT(MAXNRAW),SCINTHIT(MAXNRAW),
     + ORIENT(MAXNRAW),NTHIT(MAXNRAW)
       REAL XHIT(MAXNRAW),YHIT(MAXNRAW),ZHIT(MAXNRAW),ELOSS(MAXNRAW)
       COMMON/RAWHIT/NHIT,MODHIT,SCINTHIT,ORIENT,
     +  NTHIT,XHIT,YHIT,ZHIT,ELOSS
C
C Raw Side hits
C
       INTEGER MAXSIDEHIT
       PARAMETER (MAXSIDEHIT=500)
       INTEGER NHSIDE,QUADHIT(MAXSIDEHIT),LAYERHIT(MAXSIDEHIT)
       INTEGER SSCINT(MAXSIDEHIT),SIDETHIT(MAXSIDEHIT),
     +    SIDEPHIT(MAXSIDEHIT)
       REAL SXHIT(MAXSIDEHIT),SYHIT(MAXSIDEHIT),SZHIT(MAXSIDEHIT)
       REAL SELOSS(MAXSIDEHIT)
       COMMON/RAWSIDE/NHSIDE,QUADHIT,LAYERHIT,SSCINT,
     +  SIDETHIT,SIDEPHIT,SXHIT,SYHIT,SZHIT,SELOSS
C
C Raw barrel hits if using one
C
       INTEGER MAXBARHIT
       PARAMETER (MAXBARHIT=500)
       INTEGER NHBAR,BPLATEHIT(MAXBARHIT),BTOWERHIT(MAXBARHIT),
     +  BLAYERHIT(MAXBARHIT),BSCINTHIT(MAXBARHIT),BSIDETHIT(MAXBARHIT),
     +  BSIDEPHIT(MAXBARHIT)
       REAL BSXHIT(MAXBARHIT),BSYHIT(MAXBARHIT),BSZHIT(MAXBARHIT)
       REAL BSELOSS(MAXBARHIT)
       COMMON/RAWBAR/NHBAR,BPLATEHIT,BTOWERHIT,BLAYERHIT,BSCINTHIT,
     +  BSIDETHIT,BSIDEPHIT,BSXHIT,BSYHIT,BSZHIT,BSELOSS
C
C Digitised barrel hits
C
       INTEGER MAXBARDIG
       PARAMETER (MAXBARDIG=500)
       INTEGER NDBAR,BPLATEDIG(MAXBARDIG),BTOWERDIG(MAXBARDIG),
     +  BLAYERDIG(MAXBARDIG),BSCINTDIG(MAXBARDIG),BEOBS(MAXBARDIG)
       INTEGER BTRKDIG(4,MAXBARDIG),BORIENTDIG(MAXBARDIG)
       COMMON/DIGBAR/NDBAR,BPLATEDIG,BTOWERDIG,BLAYERDIG,BSCINTDIG,
     +  BEOBS,BTRKDIG,BORIENTDIG
C
C Digitised hits
C
       INTEGER NMAXDIG
       PARAMETER (NMAXDIG = 3000)
       INTEGER NDIG,MODDIG(NMAXDIG),SCINTDIG(NMAXDIG),
     +  ORIENTDIG(NMAXDIG),EOBS(NMAXDIG)
       REAL ZDIG(NMAXDIG),TDIG(NMAXDIG)
       INTEGER TRKDIG(4,NMAXDIG)
       COMMON/DIGHIT/NDIG,MODDIG,SCINTDIG,ORIENTDIG,TRKDIG,
     +  EOBS,ZDIG,TDIG
C
C Reconstructed tracks
C
       INTEGER MAXRECON
       PARAMETER (MAXRECON = 50)
       INTEGER NRECON, TRK(MAXRECON), IPTRK(MAXRECON), NRECHIT(MAXRECON)
       INTEGER ISTARTV(MAXRECON), IENDV(MAXRECON), NSAMPLE(MAXRECON)
       REAL STARTPOS(3, MAXRECON), ENDPOS(3, MAXRECON)
       REAL STARTDIR(3, MAXRECON), ENDDIR(3, MAXRECON)
       INTEGER startLayer(MAXRECON), endLayer(MAXRECON)
       REAL RANGE(MAXRECON), PIDCHI2(3, MAXRECON), EDEP(MAXRECON)
       REAL STARTMOM(MAXRECON), ENDMOM(MAXRECON), SEEDMOM(MAXRECON)
       REAL EOUT(MAXRECON), PELECTRON(MAXRECON), PMUON(MAXRECON)
       REAL PPION(MAXRECON), PKAON(MAXRECON), PPROTON(MAXRECON), 
     +      CHI2REC(MAXRECON)
       COMMON /RECTRK/ NRECON, TRK, IPTRK, ISTARTV, IENDV, 
     +                 NRECHIT, CHI2REC,
     +                 STARTPOS, ENDPOS, STARTDIR, ENDDIR, 
     +                 STARTLAYER, ENDLAYER,
     +                 STARTMOM, ENDMOM, SEEDMOM,
     +                 RANGE, EDEP, PIDCHI2,
     +                 NSAMPLE, EOUT, PELECTRON, PMUON, 
     +                 PPION, PKAON, PPROTON
C
C Absorber geometry
C        
      INTEGER maxAbsSections
      PARAMETER (maxAbsSections = 10)
      INTEGER aType, nAbsSections
      REAL aThickness, aDensity(maxAbsSections), 
     + aRadLen(maxAbsSections)
      REAL aInner(maxAbsSections), aOuter(maxAbsSections), 
     + aField(maxAbsSections)

      COMMON /GEOABS/ nAbsSections, aType, aThickness, 
     +                aDensity, aRadLen,
     &                aInner, aOuter, aField
C
C Module (scintillator plane) geometry
C
      INTEGER mType, mStrips, mStripShape
      REAL mThickness, mRho, mRadLen, mStripWidth, mStripLength
      REAL mRhoStrip, mRadStrip
      COMMON /GEOMOD/ mType, mStrips, mStripShape, mThickness,
     &                mStripWidth, mStripLength,
     &                mRho, mRadLen, mRhoStrip, mRadStrip
C
C Detector geometry
C
      INTEGER maxNstrip
      PARAMETER (maxNstrip = 1000)
      INTEGER gStrips, gDete, gModule, gView, gmType
      REAL gxStrip(maxNstrip), gyStrip(maxNstrip), 
     +     gzStrip(maxNstrip),glStrip(maxNstrip),
     +     gaStrip
      REAL gxModule, gyModule, gzModule
      COMMON/GEODET/ gStrips, gDete, gModule, gView, gxModule,
     +               gyModule, gzModule, gmType,
     &               gxStrip,gyStrip,gzStrip,glStrip,gaStrip
      INTEGER maxFB 
      PARAMETER (maxFB = 50)
      INTEGER gnBack, gnFwd, gvBack(maxFB), gvFwd(maxFB)
      COMMON/GEOBCK/ gnBack, gvBack
      COMMON/GEOFWD/ gnFwd, gvFwd
C
C  OD geometry
C
      INTEGER goStrips, goDete, goModule, gomType
      REAL goxModule, goyModule, gozModule
      INTEGER goViewStrip(maxNstrip), goTowerStrip(maxNstrip),
     +        goPlaneStrip(maxNstrip), goStripType(maxNstrip)
      REAL goxStrip(maxNstrip), goyStrip(maxNstrip), 
     +     gozStrip(maxNstrip),
     +     golStrip(maxNstrip), goaStrip(maxNstrip)
      COMMON/GEOOD/ goStrips, goDete, goModule, goxModule,
     +    goyModule, gozModule, gomType, 
     +    goViewStrip, goTowerStrip, goPlaneStrip, goStripType,
     +    goxStrip, goyStrip, gozStrip, golStrip, goaStrip
C
C  OD absorber geometry
C
      INTEGER noAbsSections, oaType
      REAL oaThickness, oaDensity(maxAbsSections), 
     +     oaRadLen(maxAbsSections),
     +     oaInner(maxAbsSections), oaOuter(maxAbsSections)
      COMMON/GEOABO/ noAbsSections, oaType, oaThickness,
     +               oaDensity, oaRadLen, oaInner, oaOuter
C
C  OD plane geometry
C
      INTEGER omStrips, omType, omStripShape
      REAL omThickness, omStripWidth, omStripLength, omRho, omRadLen,
     +     omRhoStrip, omRadStrip
      COMMON/GEOBAM/ omType, omStrips, omStripShape, omThickness,
     +               omStripWidth, omStripLength, 
     +               omRho, omRadLen, omRhoStrip, omRadStrip

C
C Plate geometry
C
      integer maxNPlates
      parameter (maxNPlates=1000)
      integer nPlates,mplate(maxnplates)
      real Xplate(maxnplates),Yplate(maxnplates),Zplate(maxnplates)
      real Bplate(maxnplates)
      common/PLATE/nPlates,Xplate,Yplate,Zplate,Mplate, Bplate

      integer maxODModules
      parameter (maxODModules=20)
      integer maxODLayers
      parameter (maxODLayers=100)
      integer maxODstrips
      parameter (maxODstrips=100)

      integer nODModules,nLayersPlate(maxODModules),
     + nStripsLayer(maxODLayers,maxODModules),
     + nODStrips(maxODModules),
     + odStripType(maxODstrips,maxODModules),
     + odStripTower(maxODstrips,maxODModules),
     + odStripLayer(maxODstrips,maxODModules),
     + odStripPlate(maxODStrips,maxODModules),
     + odStripView(maxODstrips,maxODModules)
      real odXStrip(maxODstrips,maxODModules),
     +     odYStrip(maxODstrips,maxODModules),
     +     odZStrip(maxODstrips,maxODModules),
     + odStripLen(maxODstrips,maxODModules),
     + odStripWid(maxODstrips,maxODModules),
     + odStripThick(maxODstrips,maxODModules),
     + odStripDens(maxODstrips,maxODModules),
     + odStripRadLen(maxODstrips,maxODModules)

      common/ODLayers/nODModules,nLayersPlate,nStripsLayer,
     + nODstrips, odStripType,odXStrip,
     + odYStrip,odZStrip,
     + odStripLen,odStripWid,odStripThick,odStripDens,odStripRadLen,
     + odStripView,odStripTower,odStripLayer
